@@ -1,8 +1,8 @@
 fixed_effects_model <- FixedEffectsModel(
-  response_unit = list(
+  response = list(
     vsia = units::as_units("ft^3")
   ),
-  covariate_units = list(
+  covariates = list(
     dsob = units::as_units("in")
   ),
   parameters = list(
@@ -23,46 +23,16 @@ test_that("Fixed effects model predicts correctly.", {
   expect_equal(pred, val)
 })
 
-test_that("Using a nested list as descriptor throws error.", {
-  expect_error(
-    FixedEffectsModel(
-      response_unit = list(vsia = units::as_units("ft^3")),
-      covariate_units = list(dsob = units::as_units("in")),
-      parameters = list(a = 1),
-      predict_fn = function(dsob) {
-        a * dsob
-      },
-      descriptors = list(test = list(a = 1, b = 2))
-    ),
-    "Descriptors must be coercible to a one-row tbl_df."
-  )
-})
-
-test_that("Columns with lists as their elements throws an error", {
-  expect_error(
-    FixedEffectsModel(
-      response_unit = list(vsia = units::as_units("ft^3")),
-      covariate_units = list(dsob = units::as_units("in")),
-      parameters = list(a = 1),
-      predict_fn = function(dsob) {
-        a * dsob
-      },
-      descriptors = tibble::tibble(a = list(list(1, 2, 3)))
-    ),
-    "Non-atomic descriptor:"
-  )
-})
-
 test_that("Fixed effects model_call returns correctly formatted string", {
   expect_equal(model_call(fixed_effects_model), "vsia = f(dsob)")
 })
 
 
 unitless_model <- FixedEffectsModel(
-  response_unit = list(
+  response = list(
     vsia = units::as_units("ft^3")
   ),
-  covariate_units = list(
+  covariates = list(
     dsob = units::unitless
   ),
   parameters = list(
@@ -74,9 +44,16 @@ unitless_model <- FixedEffectsModel(
   }
 )
 
-
-
 test_that("Model specified with units::unitless returns correct covariate formatting", {
   match_str <- "dsob []: diameter of the stem, outside bark at breast height"
   expect_equal(match_str, .get_variable_descriptions_fmt(unitless_model)[[2]])
 })
+
+test_that("Identical fixed effects models are equal", {
+  expect_equal(fixed_effects_model, fixed_effects_model)
+})
+
+
+test_that("Different fixed effects models are equal", {
+  expect_equal(fixed_effects_model == unitless_model, FALSE)
+})
\ No newline at end of file
